@@ -29,70 +29,63 @@
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(0, Qt::FramelessWindowHint),
     ui(new Ui::MainWindow)
+{
+    ui->setupUi(this);
+    SetupThisUi();
+}
+
+
+
+void MainWindow::showEvent(QShowEvent* event)
 {
 #ifdef Q_WS_HILDON
     QCoreApplication::instance()->setApplicationName("simplenotewidget");
-    // Get required atoms
-    Atom winTypeAtom = XInternAtom(QX11Info::display(), "_NET_WM_WINDOW_TYPE", false);
+
     Atom homeAppletAto = XInternAtom(QX11Info::display(), "_HILDON_WM_WINDOW_TYPE_HOME_APPLET", false);
-    Atom appletIDAtom = XInternAtom(QX11Info::display(), "_HILDON_APPLET_ID", false);
     Atom utf8Atom = XInternAtom(QX11Info::display(), "UTF8_STRING", false);
-    Atom appletSettingAtom = XInternAtom(QX11Info::display(), "_HILDON_APPLET_SETTINGS", false);
 
-    // Set correct window type
-    XChangeProperty(QX11Info::display(), winId(), winTypeAtom, XA_ATOM, 32,
-                    PropModeReplace, (unsigned char *) &homeAppletAto, 1);
-
-    // Use application name to fill AppletID
+    XChangeProperty(QX11Info::display(), winId(), XInternAtom(QX11Info::display(), "_NET_WM_WINDOW_TYPE", false), XA_ATOM, 32, PropModeReplace, (unsigned char *) &homeAppletAto, 1);
     QByteArray id (QCoreApplication::instance()->applicationName().remove(' ').toUtf8());
-    XChangeProperty(QX11Info::display(), winId(), appletIDAtom, utf8Atom, 8,
-                    PropModeReplace, (unsigned char *)id.constData(), id.length());
-
-    // Add setting button. This button is shown when hildon-desktop is in edit mode.
+    XChangeProperty(QX11Info::display(), winId(), XInternAtom(QX11Info::display(), "_HILDON_APPLET_ID", false), utf8Atom, 8,PropModeReplace, (unsigned char *)id.constData(), id.length());
     int settings = 0;
-    XChangeProperty(QX11Info::display(), winId(), appletSettingAtom, XA_CARDINAL, 32,
-                    PropModeReplace, (unsigned char*)&settings, 1);
+    XChangeProperty(QX11Info::display(), winId(), XInternAtom(QX11Info::display(), "_HILDON_APPLET_SETTINGS", false), XA_CARDINAL, 32, PropModeReplace, (unsigned char*)&settings, 1);
+    bool all_desktops =false;
+    XChangeProperty(QX11Info::display(), winId(), XInternAtom(QX11Info::display(), "_HILDON_APPLET_DISPLAY_ON_ALL_VIEWS", false),XA_CARDINAL, 32, PropModeReplace,(unsigned char *) &all_desktops, 1);
 
 #endif
-    ui->setupUi(this);
-
-
-
-
-
-   SetupThisUi();
-
-
 
 }
 
 
 
-
-
-
-
 #ifdef Q_WS_HILDON
     //Filter show setting requests
-    bool MainWindow::x11Event ( XEvent * event )
+    bool MainWindow::x11Event(XEvent* event)
     {
         static Atom appletShowSettingAtom = XInternAtom(QX11Info::display(), "_HILDON_APPLET_SHOW_SETTINGS", false);
         if (event->xclient.message_type == appletShowSettingAtom )
         {
-          //QMessageBox::information(0, "Settings", "will implement this in a future release", QMessageBox::Ok);
-          settingsdlg w(0);
-          //w->setAttribute(Qt::WA_Maemo5StackedWindow);
-          w.setProperty("FingerScrollable", true);
-          w.exec();
+          settingsdlg *w;
+          w = new settingsdlg(0);
+          w->exec();
           SetupThisUi();
-
-
+          delete w;
           return true;
         }
      return false;
     }
 #endif
 
+void MainWindow::on_pbEdit_clicked()
+{
+        Dialog *w;
+        w = new Dialog(0);
+        w->exec();
+        SetupThisUi();
+        delete w;
+}
+
+
 void MainWindow::SetupThisUi()
 {
 
@@ -133,8 +126,6 @@ void MainWindow::SetupThisUi()
     this->setAttribute(Qt::WA_StyledBackground, false);
 
 
-
-
     QSize oMovSize;
     oMovSize.setHeight(21);
     oMovSize.setWidth(21);
@@ -156,7 +147,6 @@ void MainWindow::SetupThisUi()
     ui->teMain->setWordWrapMode(QTextOption::WrapAtWordBoundaryOrAnywhere);
     ui->teMain->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     ui->teMain->setReadOnly(true);
-
     ui->teMain->setStyleSheet( "background-color: rgba( 255, 255, 0, 0% );" );
 
 
@@ -189,8 +179,6 @@ void MainWindow::SetupThisUi()
    ui->centralWidget->repaint();
    this->repaint();
 
-   //ui->lblDate->setText(fontFamilyName);
-
 }
 
 
@@ -215,15 +203,4 @@ void MainWindow::changeEvent(QEvent *e)
 
 
 
-void MainWindow::on_pbEdit_clicked()
-{
-    SetupThisUi();
-    //settingsdlg w(0);
-    Dialog w(0);
-    w.exec();
-    QSettings *oSettings;
-    oSettings = new QSettings("janbergmann", "simplenotewidget");
-    ui->teMain->setText(oSettings->value("note","").toString());
-    ui->lblDate->setText(oSettings->value("notedate",QDateTime::currentDateTime().toString("dd.MM.yyyy   HH:mm")).toString());
-    delete oSettings;
-}
+
