@@ -1,8 +1,10 @@
+
 #include "settingsdlg.h"
 #include "ui_settingsdlg.h"
 #include "qtcolorcombobox.h"
 #include <QSettings>
 #include <QScrollArea>
+#include <QVariant>
 
 
 
@@ -14,17 +16,40 @@ settingsdlg::settingsdlg(QWidget *parent) :
     this->setWindowTitle("Edit settings");
 
 
+
+
+
+
     QSettings *oSettings;
     oSettings = new QSettings("janbergmann", "simplenotewidget");
     QColor cldefault = oSettings->value("bgcolor", QColor(255,255,0)).value<QColor>();
     QColor cllabelcolor = oSettings->value("lblcolor", QColor(0,0,0)).value<QColor>();
     QColor cltextedit = oSettings->value("txtcolor", QColor(0,0,0)).value<QColor>();
-    ui->sbTransparency->setValue(oSettings->value("bgcoloralpha", int(180)).toInt());
+    int iTransparency = oSettings->value("bgcoloralpha", int(180)).toInt();
 
     int fontSizeIndex = oSettings->value("fontsize", int(1)).toInt();
     QString fontFamilyName = oSettings->value("fontfamily", "Nokia Sans SemiBold").toString();
 
 
+
+
+
+    int iIndex = 0;
+    int iCount = 0;
+    for(int i=10; i < 260; i = i + 10)
+    {
+         QVariant v = i;
+         ui->cbtransparency->addItem(v.toString());
+         if (i==iTransparency)
+         {
+             iIndex = iCount;
+         }
+         iCount++;
+
+    }
+
+    ui->cbtransparency->setCurrentIndex(iIndex);
+
     ui->cbFontSize->addItem("6");
     ui->cbFontSize->addItem("8");
     ui->cbFontSize->addItem("10");
@@ -100,7 +125,7 @@ void settingsdlg::on_pbSave_clicked()
     QColor cltextedit = cbtxt->currentColor();
 
 
-    oSettings->setValue("bgcoloralpha",ui->sbTransparency->value());
+    oSettings->setValue("bgcoloralpha",ui->cbtransparency->currentText());
     oSettings->setValue("bgcolor",cldefault);
     //oSettings.setValue("lblcolor",cllabelcolor);
     oSettings->setValue("txtcolor",cltextedit);
